@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 compilers = {}
 
 
@@ -33,7 +35,6 @@ def compile(what, mimetype, cwd=None, uri_cwd=None, debug=None):
                             uri_cwd=uri_cwd, debug=debug)
 
 
-from .css import CssCompiler
 from .sass import SassCompiler
 from .less import LessCompiler
 from .javascript import JavaScriptCompiler
