@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 from rjsmin import jsmin
 from six import with_metaclass
 
@@ -10,4 +12,6 @@ class JavaScriptCompiler(with_metaclass(CompilerMeta, object)):
     @classmethod
     def compile(cls, what, mimetype='text/javascript', cwd=None,
                 uri_cwd=None, debug=None):
+        if debug:
+            return what
         return jsmin(what)
